@@ -601,7 +601,7 @@ build_error_string (const char *source_name, const char *target_name,
 						  "permissions to change it or its parent folder.");
 				break;
 			case ERROR_SOURCE_IN_TARGET:
-				*error_string = g_strdup (_("Error while moving. "));
+				*error_string = g_strdup (_("Error while moving."));
 				detail_format = _("Cannot move \"%s\" because it or its parent folder "
 						  "are contained in the destination.");
 				break;
@@ -1484,8 +1484,19 @@ get_next_duplicate_name (char *name, int count_increment)
 
 	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
 					     NULL, NULL, NULL);
-	g_free (unescaped_tmp_name);
+	if (!unescaped_name) {
+		/* Couldn't convert to utf8 - probably
+		 * G_BROKEN_FILENAMES not set when it should be.
+		 * Try converting from the locale */
+		unescaped_name = g_locale_to_utf8 (unescaped_tmp_name, -1, NULL, NULL, NULL);	
 
+		if (!unescaped_name) {
+			unescaped_name = eel_make_valid_utf8 (unescaped_tmp_name);
+		}
+	}
+		
+	g_free (unescaped_tmp_name);
+	
 	unescaped_result = get_duplicate_name (unescaped_name, count_increment);
 	g_free (unescaped_name);
 
