@@ -66,6 +66,8 @@ typedef enum {
 	NAUTILUS_ICON_LABEL_POSITION_BESIDE
 } NautilusIconLabelPosition;
 
+#define	NAUTILUS_ICON_CONTAINER_TYPESELECT_FLUSH_DELAY 1000000
+
 typedef struct NautilusIconContainerDetails NautilusIconContainerDetails;
 
 typedef struct {
@@ -116,11 +118,14 @@ typedef struct {
 						   NautilusIconData *data,
 						   GList **emblem_icons,
 						   char **embedded_text,
-						   gboolean *embedded_text_needs_loading);
+						   gboolean *embedded_text_needs_loading,
+						   gboolean *has_window_open);
 	void         (* get_icon_text)            (NautilusIconContainer *container,
 						   NautilusIconData *data,
 						   char **editable_text,
 						   char **additional_text);
+	char *       (* get_icon_description)     (NautilusIconContainer *container,
+						   NautilusIconData *data);
 	int          (* compare_icons)            (NautilusIconContainer *container,
 						   NautilusIconData *icon_a,
 						   NautilusIconData *icon_b);
@@ -266,5 +271,7 @@ void              nautilus_icon_container_set_margins                   (Nautilu
 									 int                     bottom_margin);
 void              nautilus_icon_container_set_use_drop_shadows          (NautilusIconContainer  *container,
 									 gboolean                use_drop_shadows);
+char*             nautilus_icon_container_get_icon_description          (NautilusIconContainer  *container,
+                                                                         NautilusIconData       *data);
 
 #endif /* NAUTILUS_ICON_CONTAINER_H */
