@@ -66,6 +66,9 @@ struct NautilusViewDetails {
 
 	NautilusIdleQueue       *incoming_queue;
 	NautilusIdleQueue       *outgoing_queue;
+
+	gboolean have_window_type;
+	Nautilus_WindowType window_type;
 };
 
 typedef void (* ViewFunction) (NautilusView *view,
@@ -76,6 +79,8 @@ typedef struct {
 	char *location;
 	GList *selection;
 	char *title;
+	Nautilus_ViewFrame_OpenMode mode;
+	Nautilus_ViewFrame_OpenFlags flags;
 } LocationPlus;
 
 BONOBO_CLASS_BOILERPLATE_FULL (NautilusView, nautilus_view, Nautilus_View,
@@ -217,7 +222,6 @@ history_dup (const Nautilus_History *history)
 	for (i = 0; i < length; i++) {
 		dup->_buffer[i].title = CORBA_string_dup (history->_buffer[i].title);
 		dup->_buffer[i].location = CORBA_string_dup (history->_buffer[i].location);
-		dup->_buffer[i].icon = CORBA_string_dup (history->_buffer[i].icon);
 	}
 	CORBA_sequence_set_release (dup, CORBA_TRUE);
 
@@ -557,38 +561,8 @@ free_location_plus_callback (gpointer callback_data)
 }
 
 static void
-call_open_location_in_this_window (NautilusView *view,
-				   gpointer callback_data)
-{
-	CORBA_Environment ev;
-	Nautilus_ViewFrame view_frame;
-	
-	view_frame = view_frame_call_begin (view, &ev);
-	if (view_frame != CORBA_OBJECT_NIL) {
-		Nautilus_ViewFrame_open_location_in_this_window
-			(view_frame, callback_data, &ev);
-	}
-	view_frame_call_end (view_frame, &ev);
-}
-
-static void
-call_open_location_prefer_existing_window (NautilusView *view,
-					   gpointer callback_data)
-{
-	CORBA_Environment ev;
-	Nautilus_ViewFrame view_frame;
-	
-	view_frame = view_frame_call_begin (view, &ev);
-	if (view_frame != CORBA_OBJECT_NIL) {
-		Nautilus_ViewFrame_open_location_prefer_existing_window
-			(view_frame, callback_data, &ev);
-	}
-	view_frame_call_end (view_frame, &ev);
-}
-
-static void
-call_open_location_force_new_window (NautilusView *view,
-				     gpointer callback_data)
+call_open_location (NautilusView *view,
+		    gpointer callback_data)
 {
 	LocationPlus *location_plus;
 	CORBA_Environment ev;
@@ -600,13 +574,14 @@ call_open_location_force_new_window (NautilusView *view,
 	view_frame = view_frame_call_begin (view, &ev);
 	if (view_frame != CORBA_OBJECT_NIL) {
 		uri_list = nautilus_uri_list_from_g_list (location_plus->selection);
-		Nautilus_ViewFrame_open_location_force_new_window
-			(view_frame, location_plus->location, uri_list, &ev);
+		Nautilus_ViewFrame_open_location
+			(view_frame, location_plus->location, location_plus->mode, location_plus->flags, uri_list, &ev);
 		CORBA_free (uri_list);
 	}
 	view_frame_call_end (view_frame, &ev);
 }
 
+
 static void
 call_report_location_change (NautilusView *view,
 			     gpointer callback_data)
@@ -789,40 +764,23 @@ call_close_window (NautilusView *view,
 	view_frame_call_end (view_frame, &ev);
 }
 
-
 void
-nautilus_view_open_location_in_this_window (NautilusView *view,
-					    const char *location)
-{
-	queue_outgoing_call (view,
-			     call_open_location_in_this_window,
-			     g_strdup (location),
-			     g_free);
-}
-
-void
-nautilus_view_open_location_prefer_existing_window (NautilusView *view,
-						    const char *location)
-{
-	queue_outgoing_call (view,
-			     call_open_location_prefer_existing_window,
-			     g_strdup (location),
-			     g_free);
-}
-
-void
-nautilus_view_open_location_force_new_window (NautilusView *view,
-					      const char *location,
-					      GList *selection)
+nautilus_view_open_location (NautilusView *view,
+			     const char *location,
+			     Nautilus_ViewFrame_OpenMode mode,
+			     Nautilus_ViewFrame_OpenFlags flags,
+			     GList *selection)
 {
 	LocationPlus *location_plus;
-
+	
 	location_plus = g_new0 (LocationPlus, 1);
 	location_plus->location = g_strdup (location);
 	location_plus->selection = str_list_copy (selection);
-
+	location_plus->mode = mode;
+	location_plus->flags = flags;
+	
 	queue_outgoing_call (view,
-			     call_open_location_force_new_window,
+			     call_open_location,
 			     location_plus,
 			     free_location_plus_callback);
 }
@@ -1052,3 +1010,44 @@ nautilus_view_set_listener_mask (NautilusView *view,
 	view->details->listener_mask = mask;
 	update_listener (view);
 }
+
+Nautilus_WindowType
+nautilus_view_get_window_type (NautilusView *view)
+{
+        Bonobo_PropertyBag bag;
+        BonoboArg *arg;
+        CORBA_Environment ev;
+
+	if (view->details->have_window_type) {
+		return view->details->window_type;
+	}
+	
+	view->details->have_window_type = TRUE;
+
+        CORBA_exception_init (&ev);
+
+        bag = nautilus_view_get_ambient_properties (view, &ev);
+	
+	view->details->window_type = Nautilus_WINDOW_SPATIAL;
+
+	if (!BONOBO_EX (&ev)) {
+		arg = Bonobo_PropertyBag_getValue (bag, "window-type", &ev);
+		
+		if (!BONOBO_EX (&ev)) {
+			view->details->window_type = BONOBO_ARG_GET_GENERAL (arg, 
+									     TC_Nautilus_WindowType,
+									     Nautilus_WindowType,
+									     NULL);
+			CORBA_free (arg);
+		} else {
+			g_warning ("Window type not found in view frame properties.");
+		}
+
+		bonobo_object_release_unref (bag, &ev);
+	} else {
+		g_warning ("Couldn't get ambient properties for the view frame.");
+	}
+	CORBA_exception_free (&ev);
+
+	return view->details->window_type;
+}
